import re

# // Equation class
class Equation(object):
    def __init__(self, content: str, enumerate: bool = False) -> None:
        self.content = re.sub("\s\s+", " ", content).strip()
        self.enumerate = enumerate

    def __str__(self) -> str:
        self.content = self.content.replace(" ", "\\;")
        type: str = '*'  if not self.enumerate else ''
        return f"\\begin{{equation{type}}}{self.content}\\end{{equation{type}}}"

# // Text class
class Text(object):
    def __init__(self, content: str, b: bool = False, it: bool = False) -> None:
        self.content = re.sub("\s\s+", " ", content).strip()
        self.bold = b
        self.italic = it
    
    def __str__(self) -> str:
        if self.bold:
            return f"\\textbf{{{self.content}}}"
        elif self.italic:
            return f"\\textit{{{self.content}}}"
        elif self.italic and self.bold:
            return f"\\textbf{{\\textit{{{self.content}}}}}"
        return f"{{{self.content}}}"
    




# // List class
class List(object):
    def __init__(self, type: str = "itemize", items: list[any] = []) -> None:
        self.type = type
        self.items = items
        
    def __str__(self) -> str:
        return (
            f"\\begin{{{self.type}}}" +
            "".join(f"\\item {{{i}}}" for i in self.items) +
            f"\\end{{{self.type}}}\\leavevmode"
        )


# // Line List class
class LineList(object):
    def __init__(self, type: str = "itemize", content: str = ""):
        self.type = type
        self.content = content

    def __str__(self) -> str:
        self.content = self.content.strip().split("\n")
        return str(List(
            type=self.type, items=[i for i in self.content if len(i) > 0]
        ))